API
=====================

The ``AuthenticationView`` class
********************************
.. autoclass:: pfx.pfxcore.views.AuthenticationView
    :members:
    :undoc-members:
    :show-inheritance:

The ``ForgottenPasswordView`` class
***********************************
.. autoclass:: pfx.pfxcore.views.ForgottenPasswordView
    :members:
    :undoc-members:
    :show-inheritance:

The ``DetailRestViewMixin`` class
*********************************
.. autoclass:: pfx.pfxcore.views.DetailRestViewMixin
    :members:
    :undoc-members:
    :show-inheritance:

.. :inherited-members:

The ``LocaleMiddleware`` class
******************************
.. autoclass:: pfx.pfxcore.middleware.LocaleMiddleware
    :members:
    :undoc-members:
    :show-inheritance:

The ``LocaleRestView`` class
****************************
.. autoclass:: pfx.pfxcore.views.LocaleRestView
    :members:
    :undoc-members:
    :show-inheritance:

The ``ModelMixin`` class
************************
.. autoclass:: pfx.pfxcore.views.ModelMixin
    :members:
    :undoc-members:
    :show-inheritance:
